searchData={"content_type":"text/markdown","items":[{"doc":"ExLiveTable is a comprehensive data table solution for Phoenix LiveView applications.\n\nIt provides responsive tables with built-in sorting, filtering, pagination, and export\nfunctionality. The table automatically adapts between desktop and mobile views.","ref":"ExLiveTable.html","title":"ExLiveTable","type":"module"},{"doc":"- Responsive design with desktop and mobile views\n- Sorting by columns\n- Quick search filter\n- Pagination with Scrivener integration\n- CSV/Excel/PDF export functionality\n- Customizable styling","ref":"ExLiveTable.html#module-features","title":"Features - ExLiveTable","type":"module"},{"doc":"```elixir\n \n  <:col :let={user} label=\"ID\"><%= user.id %></:col>\n  <:col :let={user} label=\"Username\"><%= user.username %></:col>\n  <:action :let={user}>\n     Edit \n  </:action>\n \n```","ref":"ExLiveTable.html#module-basic-usage","title":"Basic Usage - ExLiveTable","type":"module"},{"doc":"In your LiveView, handle the table events:\n\n```elixir\ndef handle_event(\"iSearch\", %{\"isearch\" => search_term}, socket) do\n  # Update your query with search term\n  {:noreply, assign(socket, search_term: search_term)}\nend\n\ndef handle_event(\"refresh_table\", _, socket) do\n  # Reload data\n  {:noreply, assign(socket, users: reload_users())}\nend\n\ndef handle_event(\"filter\", _, socket) do\n  # Show filter modal\n  {:noreply, socket}\nend\n\ndef handle_event(\"export\", %{\"file_type\" => file_type}, socket) do\n  # Handle export based on file_type (csv, xlsx, pdf)\n  {:noreply, socket}\nend\n```","ref":"ExLiveTable.html#module-liveview-integration","title":"LiveView Integration - ExLiveTable","type":"module"},{"doc":"Handles search filtering in your LiveView when using Ecto.\n\nNote: This function requires Ecto to be installed.","ref":"ExLiveTable.html#handle_search/2","title":"ExLiveTable.handle_search/2","type":"function"},{"doc":"```elixir\ndef handle_event(\"iSearch\", %{\"isearch\" => search_term}, socket) do\n  params = put_in(socket.assigns.params, [\"filter\", \"isearch\"], search_term)\n\n  {:noreply, push_patch(socket, to: \"?\" <> ExLiveTable.querystring(params))}\nend\n```","ref":"ExLiveTable.html#handle_search/2-example-usage-in-liveview","title":"Example usage in LiveView - ExLiveTable.handle_search/2","type":"function"},{"doc":"Handles sorting in your LiveView when using Ecto.\n\nNote: This function requires Ecto to be installed.","ref":"ExLiveTable.html#handle_sorting/2","title":"ExLiveTable.handle_sorting/2","type":"function"},{"doc":"```elixir\ndef handle_params(params, _url, socket) do\n  query = ExLiveTable.handle_sorting(User, params)\n  users = Repo.paginate(query, params)\n\n  {:noreply, assign(socket, users: users, params: params)}\nend\n```","ref":"ExLiveTable.html#handle_sorting/2-example-usage-in-liveview","title":"Example usage in LiveView - ExLiveTable.handle_sorting/2","type":"function"},{"doc":"","ref":"ExLiveTable.html#main_table/1","title":"ExLiveTable.main_table/1","type":"function"},{"doc":"","ref":"ExLiveTable.html#querystring/2","title":"ExLiveTable.querystring/2","type":"function"},{"doc":"","ref":"ExLiveTable.html#sort/1","title":"ExLiveTable.sort/1","type":"function"},{"doc":"","ref":"ExLiveTable.html#table_link/3","title":"ExLiveTable.table_link/3","type":"function"},{"doc":"Provides helper functions for table sorting, pagination, and query string operations.","ref":"ExLiveTable.DataTable.html","title":"ExLiveTable.DataTable","type":"module"},{"doc":"Handles the empty table state, displaying a loading spinner or \"No data\" message.","ref":"ExLiveTable.DataTable.html#empty_table/1","title":"ExLiveTable.DataTable.empty_table/1","type":"function"},{"doc":"* `data_loader` (`:boolean`) - Defaults to `true`.","ref":"ExLiveTable.DataTable.html#empty_table/1-attributes","title":"Attributes - ExLiveTable.DataTable.empty_table/1","type":"function"},{"doc":"Renders a search input box that triggers an \"iSearch\" event on change.","ref":"ExLiveTable.DataTable.html#isearch/1","title":"ExLiveTable.DataTable.isearch/1","type":"function"},{"doc":"* `params` (`:map`) - Defaults to `%{\"filter\" => %{\"isearch\" => \"\"}}`.","ref":"ExLiveTable.DataTable.html#isearch/1-attributes","title":"Attributes - ExLiveTable.DataTable.isearch/1","type":"function"},{"doc":"Builds a query string from the current params and options.\nUsed for pagination and sorting links.","ref":"ExLiveTable.DataTable.html#querystring/2","title":"ExLiveTable.DataTable.querystring/2","type":"function"},{"doc":"iex> querystring(%{\"page\" => \"1\"}, sort_field: :name, sort_direction: \"desc\")\n    \"page=1&sort_field=name&sort_direction=desc\"","ref":"ExLiveTable.DataTable.html#querystring/2-examples","title":"Examples - ExLiveTable.DataTable.querystring/2","type":"function"},{"doc":"Parses sort parameters from URL query parameters.\nReturns a tuple of {sort_direction, sort_field}.","ref":"ExLiveTable.DataTable.html#sort/1","title":"ExLiveTable.DataTable.sort/1","type":"function"},{"doc":"iex> sort(%{\"sort_field\" => \"name\", \"sort_direction\" => \"asc\"})\n    {:asc, :name}\n\n    iex> sort(%{\"sort_field\" => \"created_at\", \"sort_direction\" => \"desc\"})\n    {:desc, :created_at}\n\n    iex> sort(%{})\n    {:asc, :id}","ref":"ExLiveTable.DataTable.html#sort/1-examples","title":"Examples - ExLiveTable.DataTable.sort/1","type":"function"},{"doc":"Creates a table header link for sorting with proper direction switching.","ref":"ExLiveTable.DataTable.html#table_link/3","title":"ExLiveTable.DataTable.table_link/3","type":"function"},{"doc":"iex> table_link(%{\"sort_field\" => \"name\", \"sort_direction\" => \"asc\"}, \"Name\", :name)\n    # Returns a LiveView link to sort by name in desc order","ref":"ExLiveTable.DataTable.html#table_link/3-examples","title":"Examples - ExLiveTable.DataTable.table_link/3","type":"function"},{"doc":"Renders a responsive data table with sorting, filtering, and pagination.\n\nThis component provides both desktop and mobile views, built-in search,\nand export functionality.","ref":"ExLiveTable.MainTable.html","title":"ExLiveTable.MainTable","type":"module"},{"doc":"Renders a table with generic styling.","ref":"ExLiveTable.MainTable.html#main_table/1","title":"ExLiveTable.MainTable.main_table/1","type":"function"},{"doc":"<:col :let={user} label=\"ID\"><%= user.id %></:col>\n      <:col :let={user} label=\"Username\"><%= user.username %></:col>\n      <:action :let={user}>\n         Edit \n      </:action>","ref":"ExLiveTable.MainTable.html#main_table/1-examples","title":"Examples - ExLiveTable.MainTable.main_table/1","type":"function"},{"doc":"* `id` (`:string`) (required)\n* `rows` (`:list`) (required)\n* `extraction` (`:boolean`) - Defaults to `true`.\n* `params` (`:map`) (required)\n* `row_id` (`:any`) - the function for generating the row id. Defaults to `nil`.\n* `data_loader` (`:boolean`) - indicates if data is currently loading. Defaults to `false`.\n* `row_click` (`:any`) - the function for handling phx-click on each row. Defaults to `nil`.\n* `row_item` (`:any`) - the function for mapping each row before calling the :col and :action slots. Defaults to `&Function.identity/1`.","ref":"ExLiveTable.MainTable.html#main_table/1-attributes","title":"Attributes - ExLiveTable.MainTable.main_table/1","type":"function"},{"doc":"* `col` (required) - Accepts attributes:\n\n  * `label` (`:string`)\n  * `label_class` (`:string`)\n  * `class` (`:string`)\n* `action` - the slot for showing user actions in the last table column.","ref":"ExLiveTable.MainTable.html#main_table/1-slots","title":"Slots - ExLiveTable.MainTable.main_table/1","type":"function"},{"doc":"LiveComponent for handling pagination in tables.\n\nThis component displays pagination controls for navigating between pages of results.\nIt supports both desktop and mobile views.","ref":"ExLiveTable.PaginationComponent.html","title":"ExLiveTable.PaginationComponent","type":"module"},{"doc":"Calculates the ending page number for pagination display.","ref":"ExLiveTable.PaginationComponent.html#end_page/2","title":"ExLiveTable.PaginationComponent.end_page/2","type":"function"},{"doc":"","ref":"ExLiveTable.PaginationComponent.html#render/1","title":"ExLiveTable.PaginationComponent.render/1","type":"function"},{"doc":"Calculates the starting page number for pagination display.","ref":"ExLiveTable.PaginationComponent.html#start_page/1","title":"ExLiveTable.PaginationComponent.start_page/1","type":"function"},{"doc":"","ref":"ExLiveTable.PaginationComponent.html#update/2","title":"ExLiveTable.PaginationComponent.update/2","type":"function"},{"doc":"# ExLiveTable\n\nA comprehensive DataTable solution for Phoenix LiveView applications with built-in sorting, filtering, pagination, and responsive design.","ref":"readme.html","title":"ExLiveTable","type":"extras"},{"doc":"The package can be installed by adding `ex_live_table` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ex_live_table, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation","title":"Installation - ExLiveTable","type":"extras"},{"doc":"- Responsive design with desktop and mobile views\n- Sorting by columns\n- Quick search filter\n- Pagination with Scrivener integration\n- CSV/Excel/PDF export functionality\n- Customizable styling","ref":"readme.html#features","title":"Features - ExLiveTable","type":"extras"},{"doc":"```elixir\n \n  <:col :let={user} label=\"ID\"><%= user.id %></:col>\n  <:col :let={user} label=\"Username\"><%= user.username %></:col>\n  <:action :let={user}>\n     Edit \n  </:action>\n \n```","ref":"readme.html#usage","title":"Usage - ExLiveTable","type":"extras"},{"doc":"The docs can be found at [https://hexdocs.pm/ex_live_table](https://hexdocs.pm/ex_live_table).\n\n# LiveTable Usage Guide\n\n`LiveTable` is a comprehensive data table solution for Phoenix LiveView applications with built-in sorting, filtering, pagination, and responsive design.","ref":"readme.html#documentation","title":"Documentation - ExLiveTable","type":"extras"},{"doc":"Here's a simple example of using LiveTable in your LiveView application:","ref":"readme.html#basic-example","title":"Basic Example - ExLiveTable","type":"extras"},{"doc":"```elixir\ndefmodule MyAppWeb.UserLive.Index do\n  use MyAppWeb, :live_view\n  alias MyApp.Accounts\n\n  @impl true\n  def mount(_params, _session, socket) do\n    {:ok, socket}\n  end\n\n  @impl true\n  def handle_params(params, _url, socket) do\n    params = params || %{}\n    page = Accounts.list_users(params)\n\n    {:noreply,\n     socket\n     |> assign(:params, params)\n     |> assign(:users, page)}\n  end\n\n  @impl true\n  def handle_event(\"iSearch\", %{\"isearch\" => search_term}, socket) do\n    params = put_in(socket.assigns.params, [\"filter\", \"isearch\"], search_term)\n    {:noreply, push_patch(socket, to: ~p\"/users?#{params}\")}\n  end\n\n  @impl true\n  def handle_event(\"refresh_table\", _, socket) do\n    {:noreply, push_patch(socket, to: ~p\"/users?#{socket.assigns.params}\")}\n  end\n\n  @impl true\n  def handle_event(\"export\", %{\"file_type\" => file_type}, socket) do\n    # Export logic for CSV, Excel, or PDF\n    users = Accounts.list_all_users(socket.assigns.params)\n    \n    case file_type do\n      \"csv\" -> generate_csv(users)\n      \"xlsx\" -> generate_xlsx(users)\n      \"pdf\" -> generate_pdf(users)\n    end\n    \n    {:noreply, socket}\n  end\nend\n```","ref":"readme.html#live-view-module","title":"Live View Module - ExLiveTable","type":"extras"},{"doc":"```heex\n Users \n\n \n  <:col :let={user} label=\"ID\"><%= user.id %></:col>\n  <:col :let={user} label=\"Name\"><%= user.name %></:col>\n  <:col :let={user} label=\"Email\"><%= user.email %></:col>\n  <:col :let={user} label=\"Role\"><%= user.role %></:col>\n  <:col :let={user} label=\"Created\">\n    <%= Calendar.strftime(user.inserted_at, \"%Y-%m-%d\") %>\n  </:col>\n  \n  <:action :let={user}>\n     \n      <.link navigate={~p\"/users/#{user}/edit\"} class=\"text-blue-600 hover:text-blue-800\">\n        Edit\n      </.link>\n       \n        Delete\n       \n     \n  </:action>\n \n```","ref":"readme.html#liveview-template","title":"LiveView Template - ExLiveTable","type":"extras"},{"doc":"```elixir\ndefmodule MyApp.Accounts do\n  import Ecto.Query\n  alias MyApp.Repo\n  alias MyApp.Accounts.User\n\n  def list_users(params) do\n    User\n    |> ExLiveTable.handle_search(params)\n    |> ExLiveTable.handle_sorting(params)\n    |> Repo.paginate(params)\n  end\n  \n  def list_all_users(params) do\n    User\n    |> ExLiveTable.handle_search(params)\n    |> ExLiveTable.handle_sorting(params)\n    |> Repo.all()\n  end\nend\n```","ref":"readme.html#context-module","title":"Context Module - ExLiveTable","type":"extras"},{"doc":"","ref":"readme.html#advanced-options","title":"Advanced Options - ExLiveTable","type":"extras"},{"doc":"```heex\n  JS.navigate(~p\"/users/#{user}\") end}>\n  <!-- columns -->\n \n```","ref":"readme.html#customizing-row-click-behavior","title":"Customizing Row Click Behavior - ExLiveTable","type":"extras"},{"doc":"```heex\n  \"user-#{user.id}\" end}\n  row_item={fn user -> Map.put(user, :full_name, \"#{user.first_name} #{user.last_name}\") end}>\n  <:col :let={user} label=\"Full Name\"><%= user.full_name %></:col>\n  <!-- more columns -->\n \n```","ref":"readme.html#dynamic-row-id-and-item-transformation","title":"Dynamic Row ID and Item Transformation - ExLiveTable","type":"extras"},{"doc":"```heex\n \n  <!-- columns -->\n \n```","ref":"readme.html#loading-state","title":"Loading State - ExLiveTable","type":"extras"},{"doc":"The ExLiveTable comes with a default styling system based on Tailwind CSS. You can customize the appearance by:\n\n1. Adding custom CSS classes to columns\n2. Overriding the default styles in your app.css\n\nExample of custom column classes:\n\n```heex\n \n  <:col :let={user} label=\"ID\" class=\"font-mono\"><%= user.id %></:col>\n  <:col :let={user} label=\"Status\" label_class=\"text-center\" class=\"text-center\">\n     \n      <%= user.status %>\n     \n  </:col>\n  <!-- more columns -->\n \n```","ref":"readme.html#styling-options","title":"Styling Options - ExLiveTable","type":"extras"},{"doc":"Make sure to add Scrivener to your dependencies:\n\n```elixir\ndefp deps do\n  [\n    {:scrivener_ecto, \"~> 2.7\"}\n  ]\nend\n```\n\nConfigure Scrivener in your repo:\n\n```elixir\ndefmodule MyApp.Repo do\n  use Ecto.Repo,\n    otp_app: :my_app,\n    adapter: Ecto.Adapters.Postgres\n\n  use Scrivener, page_size: 10\nend\n```\n\nUse Scrivener in your context:\n\n```elixir\ndef list_users(params) do\n  page = params[\"page\"] || \"1\"\n  page_size = params[\"page_size\"] || \"10\"\n\n  params = Map.merge(params, %{\n    \"page\" => page,\n    \"page_size\" => page_size\n  })\n\n  User\n  |> ExLiveTable.handle_search(params)\n  |> ExLiveTable.handle_sorting(params)\n  |> Repo.paginate(params)\nend\n```","ref":"readme.html#handling-pagination-with-scrivener","title":"Handling Pagination with Scrivener - ExLiveTable","type":"extras"},{"doc":"To implement the export functionality, you'll need additional libraries depending on the export format:\n\n- For CSV: `{:csv, \"~> 2.4\"}`\n- For Excel: `{:xlsx_creator, \"~> 0.4.2\"}`\n- For PDF: `{:pdf_generator, \"~> 0.6.2\"}`\n\nExample implementation:\n\n```elixir\ndef generate_csv(users) do\n  csv_content =\n    [[\"ID\", \"Name\", \"Email\", \"Role\", \"Created At\"]] ++\n    Enum.map(users, fn user ->\n      [\n        user.id,\n        user.name,\n        user.email,\n        user.role,\n        Calendar.strftime(user.inserted_at, \"%Y-%m-%d\")\n      ]\n    end)\n    |> CSV.encode()\n    |> Enum.to_list()\n    |> Enum.join()\n\n  # Return the CSV for download\n  %{\n    content: csv_content,\n    content_type: \"text/csv\",\n    filename: \"users_export.csv\"\n  }\nend\n```","ref":"readme.html#export-functionality","title":"Export Functionality - ExLiveTable","type":"extras"},{"doc":"For more advanced search needs, you can override the default search behavior:\n\n```elixir\ndef list_users(params) do\n  search_term = get_in(params, [\"filter\", \"isearch\"]) || \"\"\n  \n  query = from u in User\n  \n  query =\n    if search_term != \"\" do\n      search_term = \"%#{search_term}%\"\n      from u in query,\n        where:\n          ilike(u.name, ^search_term) or\n          ilike(u.email, ^search_term) or\n          ilike(u.role, ^search_term)\n    else\n      query\n    end\n    \n  query\n  |> ExLiveTable.handle_sorting(params)\n  |> Repo.paginate(params)\nend\n```","ref":"readme.html#custom-search-implementation","title":"Custom Search Implementation - ExLiveTable","type":"extras"},{"doc":"For large datasets:\n\n1. Ensure proper database indexing on sorted and filtered columns\n2. Consider using limit/offset instead of fetching all records\n3. Use `row_item` for complex transformations to avoid doing them in the template","ref":"readme.html#performance-considerations","title":"Performance Considerations - ExLiveTable","type":"extras"},{"doc":"Common issues:\n\n1. **Pagination not working**: Ensure you're using Scrivener correctly and passing the `params` to the table component\n2. **Sorting not affecting results**: Check that the field names match your database columns\n3. **Search not working**: Verify that the `iSearch` event is properly handled and the filter parameters are correctly passed","ref":"readme.html#troubleshooting","title":"Troubleshooting - ExLiveTable","type":"extras"}],"producer":{"name":"ex_doc","version":"0.37.3"},"proglang":"elixir"}